-
Analyzing your requirements and generating your app…
-
- Loading…
-
-
AppWizzy AI is collecting your requirements and applying the first changes.
-
This page will refresh automatically as the plan is implemented.
-
- Runtime: Django {{ django_version }} · Python {{ python_version }}
- — UTC {{ current_time|date:"Y-m-d H:i:s" }}
-
+
+
+
+ {% for product in products %}
+
+ {{ product.name }}
+ {{ product.description|truncatewords:15 }}
+ ETB {{ product.price }}
+ View Details →
+
+ {% empty %}
+ No products available yet.
+ {% endfor %}
-
{% endblock %}
\ No newline at end of file
diff --git a/static/css/custom.css b/static/css/custom.css
index 925f6ed..020d029 100644
--- a/static/css/custom.css
+++ b/static/css/custom.css
@@ -1,4 +1,48 @@
-/* Custom styles for the application */
-body {
- font-family: system-ui, -apple-system, sans-serif;
+/* Professional Design - Ethio-Gebeya */
+@import url('https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600&family=Manrope:wght@600;700;800&display=swap');
+
+:root {
+ --primary: #1F6FEB;
+ --secondary: #0F172A;
+ --accent: #F97316;
+ --bg: #F8FAFC;
+ --text: #1E293B;
}
+
+body {
+ font-family: 'Inter', sans-serif;
+ background-color: var(--bg);
+ color: var(--text);
+ margin: 0;
+}
+
+h1, h2, h3, .brand {
+ font-family: 'Manrope', sans-serif;
+}
+
+.hero {
+ background: linear-gradient(135deg, var(--secondary), var(--primary));
+ color: white;
+ padding: 80px 20px;
+ text-align: center;
+}
+
+.product-grid {
+ display: grid;
+ grid-template-columns: repeat(auto-fill, minmax(280px, 1fr));
+ gap: 2rem;
+ padding: 40px 20px;
+}
+
+.product-card {
+ background: white;
+ border-radius: 12px;
+ padding: 1.5rem;
+ box-shadow: 0 4px 6px -1px rgba(0,0,0,0.1);
+ transition: transform 0.2s, box-shadow 0.2s;
+}
+
+.product-card:hover {
+ transform: translateY(-5px);
+ box-shadow: 0 10px 15px -3px rgba(0,0,0,0.1);
+}
\ No newline at end of file
diff --git a/core/views.py b/core/views.py
index c9aed12..1bfab33 100644
--- a/core/views.py
+++ b/core/views.py
@@ -1,25 +1,10 @@
-import os
-import platform
-
-from django import get_version as django_version
from django.shortcuts import render
-from django.utils import timezone
-
+from .models import Product
def home(request):
- """Render the landing screen with loader and environment details."""
- host_name = request.get_host().lower()
- agent_brand = "AppWizzy" if host_name == "appwizzy.com" else "Flatlogic"
- now = timezone.now()
-
+ """Render the landing screen with products."""
+ products = Product.objects.all()
context = {
- "project_name": "New Style",
- "agent_brand": agent_brand,
- "django_version": django_version(),
- "python_version": platform.python_version(),
- "current_time": now,
- "host_name": host_name,
- "project_description": os.getenv("PROJECT_DESCRIPTION", ""),
- "project_image_url": os.getenv("PROJECT_IMAGE_URL", ""),
+ "products": products,
}
- return render(request, "core/index.html", context)
+ return render(request, "core/index.html", context)
\ No newline at end of file